@@ -6,7 +6,7 @@
 #### Paul D. McNicholas (2015)
 #### R package mixture: Mixture Models for Clustering and Classification
 ################################
-mix.compnorm <- function(x, g, model = NULL, type = "alr", veo = FALSE) {
+mix.compnorm <- function(x, g, model, type = "alr", veo = FALSE) {
   ## x is the compositional data
   ## g is the number of components to be used
   ## model is the type of model to be used
@@ -16,13 +16,15 @@ mix.compnorm <- function(x, g, model = NULL, type = "alr", veo = FALSE) {
 
   if (type == "alr") {
     y <- log(x[, -1]/x[, 1])
-  } else {
+  } else if ( type == "ilr" ) {
     y0 <- log(x)
     y1 <- y0 - Rfast::rowmeans( y0 )
     y <- tcrossprod( y1, helm(p) )
+  } else if ( type == "pivot" ) {
+    y <- Compositional::pivot(x)
   }
 
-  mod <- mixture::gpcm(y, G = g, mnames = model, start = 0, mmax = 100)
+  mod <- mixture::gpcm(y, G = g, mnames = model, start = 0, mmax = 100, veo = veo)
   param <- mod$gpar
   mu <- matrix(nrow = g, ncol = length( param[[ 1 ]]$mu) )
   su <- array( dim = c( length(param[[ 1 ]]$mu), length(param[[ 1 ]]$mu), g ) )
