@@ -17,6 +17,7 @@ norm.contour <- function(m, s, type = "alr", n = 100, x = NULL) {
   ha <- t( helm(3) )
   down <- det(2 * pi * s)^(-0.5)
   st <- solve(s)
+  f1 <- sqrt(2/3)   ;   f2 <- sqrt(0.5)
 
   for ( i in 1:c(n/2) ) {
     for ( j in 1:n ) {
@@ -29,12 +30,16 @@ norm.contour <- function(m, s, type = "alr", n = 100, x = NULL) {
         w <- c(w1, w2, w3)
         if (type == "alr") {
           y <- log( w[-1] / w[1] )  ## additive log-ratio transformation
-        } else {
+        } else if ( type == "ilr" ) {
           y <- log(w) - mean( log(w) )
-          y <- as.vector( y %*% ha )
-        }  ## isometric log-ratio transformation
+          y <- as.vector( y %*% ha )  ## isometric log-ratio transformation
+        } else {
+          y <- c( f1 * ( log(w[1]) - 0.5 * log(w[2]) - 0.5 * log(w[3]) ),
+                  f2 * log( w[2] / w[3] ) )
+        }
+
         can <- down * exp( -0.5 * ( ( y - m ) %*% st %*% ( y - m ) ) )
-        if (abs(can) < Inf)  mat[i, j] <- can
+        if ( abs(can) < Inf )  mat[i, j] <- can
       }
     }
   }
@@ -55,7 +60,7 @@ norm.contour <- function(m, s, type = "alr", n = 100, x = NULL) {
           y <- as.vector( y %*% ha )
         }  ## isometric log-ratio transformation
         can <- down * exp( -0.5 * ( ( y - m ) %*% st %*% ( y - m ) ) )
-        if (abs(can) < Inf)   mat[i, j] <- can
+        if ( abs(can) < Inf )   mat[i, j] <- can
       }
     }
   }
