@@ -23,8 +23,15 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
 
   runtime <- proc.time()
   x <- model.matrix(y ~ ., data.frame(x) )
+  p <- dim(x)[2]
   n <- dim(y)[1]  ## sample size
   d <- dim(y)[2] - 1  ## dimensionality of the simplex
+  namx <- colnames(x)
+  namy <- colnames(y)
+  if ( is.null( namy ) )  {
+    namy <- paste("Y", 1:d, sep = "")
+  } else namy <- namy[-1]
+
   ## the next lines minimize the reg function and obtain the estimated betas
   ini <- as.vector( t( lm.fit(x, y[, -1])$coefficients ) )  ## initial values
   oop <- options(warn = -1)
@@ -32,7 +39,7 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
   qa <- nlm(olsreg, qa$estimate, y = y, x = x, d = d)
   qa <- nlm(olsreg, qa$estimate, y = y, x = x, d = d)
   on.exit( options(oop) )
-  beta <- matrix(qa$estimate, byrow = TRUE, ncol = d)
+  be <- matrix(qa$estimate, byrow = TRUE, ncol = d)
   covb <- NULL
   runtime <- proc.time() - runtime
 
@@ -73,6 +80,9 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
       covb <- cov(betaboot)
       runtime <- proc.time() - runtime
     }  ## end if (nc <= 1) {
+    nam <- NULL
+    for (i in 1:p)  nam <- c(nam, paste(namy, ":", namx[i], sep = "") )
+    colnames(covb) <- rownames(covb) <- nam
   }  ## end if (B > 1) {
 
   est <- NULL
@@ -82,6 +92,7 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
     est <- mu / Rfast::rowsums(mu)
   }
 
-  rownames(beta)  <- colnames(x)
-  list(runtime = runtime, beta = beta, covbe = covb, est = est)
+  colnames(be) <- namy
+  rownames(be) <- namx
+  list(runtime = runtime, be = be, covbe = covb, est = est)
 }
